﻿Imports System.IO
Imports IWshRuntimeLibrary

Module dhmodShortCut

	''' <summary>
	''' 	 Erstellung ShortCut (Verknüpfung)
	''' </summary>
	''' <param name="folder">der Ordner, in dem die Verknüpfung erstellt wird</param>
	''' <param name="name">der Name der Verknüpfung, der angezeigt wird</param>
	''' <param name="target">die Application, die von der Verknüpfung ausgeführt wird</param>
	''' <param name="description">eine Beschreibung (Tooltip) der Verknüpfung</param>
	''' <param name="arguments">Befehlszeilenargumente für die Verknüpfung</param>
	''' <param name="iconPath">der Pfad zum Icon der Verknüpfung</param>
	''' <param name="workingdir">das Arbeitsverzeichnis der Verknüpfung</param>
	Public Sub CreateShortcut2(folder As String, name As String,
										target As String, description As String,
										arguments As String, iconPath As String,
										workingdir As String)
		Dim shortcutFullName As String = Path.Combine(folder, name + ".lnk")
		shortcutFullName = Replace(shortcutFullName, ".EXE", "")
		Try
			Dim shell As New WshShell
			Dim link As IWshShortcut =
				DirectCast(shell.CreateShortcut(shortcutFullName), IWshShortcut)
			With link
				.Arguments = arguments
				.Description = description
				.IconLocation = iconPath
				.TargetPath = target '+ ".exe"
				.WorkingDirectory = workingdir
				.Save()
			End With
		Catch ex As Exception
			MessageBox.Show(String.Format("Die Verknüpfung ""{0}"" konnte nicht erstellt werden." _
								+ vbLf + vbLf + "{1}", shortcutFullName, ex.ToString()),
								"Create Shortcut", MessageBoxButtons.OK, MessageBoxIcon.Information)
		End Try
	End Sub

	''' <summary>
	''' 	 Verknüpfungsdaten auslesen
	''' </summary>
	''' <param name="filename">der Dateiname der Verknüpfung</param>
	''' <param name="dbg">Daten im Direktfenster zeigen ja|nein</param>
	''' <returns></returns>
	Public Function ReadLnk(filename As String,
									Optional dbg As Boolean = False) As String
		Dim direc As String
		Dim shortCut As IWshShortcut
		shortCut = CType((New WshShell).CreateShortcut(filename), IWshShortcut)
		If dbg Then
			Debug.Print("")
			Debug.Print("Lnk-Datei: " & filename)
			With shortCut
				Debug.Print("Auszuführende Datei: " & .TargetPath)
				Debug.Print("Arbeitsverzeichnis: " & .WorkingDirectory)
				Debug.Print("Beschreibung: " & .Description)
				Debug.Print("Start-Parameter: " & .Arguments)
				Debug.Print("HotKey: " & .Hotkey)
				Debug.Print("Icon: " & .IconLocation)
			End With
		End If
		' Rückgabe der Verknüpfung
		If shortCut.WorkingDirectory = "" Then 'bspw. bei Office-Programmen
			direc = filename
		Else
			direc = shortCut.WorkingDirectory
		End If
		Return If(shortCut.WorkingDirectory.Contains("%"), shortCut.TargetPath, direc)
	End Function

	'überprüfen, was sich in der Zwischenablage befindet
	Public Function testClipboard()
		Dim cTyp As String
		With My.Computer.Clipboard
			If .ContainsImage Then
				cTyp = "img"
			ElseIf .ContainsAudio Then
				cTyp = "aud"
			ElseIf .ContainsFileDropList Then
				cTyp = "fdl"
			ElseIf .ContainsData("specialFormat") Then
				cTyp = "dat"
			ElseIf .ContainsText Then
				cTyp = "txt"
			Else
				cTyp = "not"
			End If
		End With
		Return cTyp
	End Function

	'lesen aus der Zwischenablage
	Public Function readClipboard(ByVal cTyp As String) As Object
		Dim obj As Object
		With My.Computer.Clipboard
			Select Case cTyp
				Case "img"
					obj = .GetImage
				Case "aud"
					obj = .GetAudioStream
				Case "fdl"
					obj = .GetFileDropList
				Case "dat"
					obj = .GetData("specialFormat")
				Case "txt"
					obj = .GetText
				Case Else
					obj = Nothing
			End Select
		End With
		Return obj
	End Function

End Module
